@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KITINERARY_PDFDOCUMENT_P_H
-#define KITINERARY_PDFDOCUMENT_P_H
+#pragma once
 
 #include <config-kitinerary.h>
 
@@ -53,5 +52,4 @@ public:
 
 }
 
-#endif
 
